@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IGroup_VERSION = "4.1.61929"
+IGroup_VERSION = "4.1.62024"
 
 class IGroup(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -167,6 +167,28 @@ class IGroup(BaseEndpoint):
 
         response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
+    def memberOf (self, uid ):
+        postUri = "/{uid}/groups";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
+    def memberOfGroups (self, uid ):
+        postUri = "/{uid}/groupUids";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def setRoles (self, uid , roles ):
         postUri = "/{uid}/roles";
         __data__ = None
