@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IInstallation_VERSION = "4.1.61929"
+IInstallation_VERSION = "4.1.62024"
 
 class IInstallation(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -290,16 +290,6 @@ class IInstallation(BaseEndpoint):
 
         response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def partialUpgrade (self, from_ , to ):
-        postUri = "/_partialUpgrade";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'from': from_  , 'to': to   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInstallation_VERSION}, data = __encoded__);
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
     def promoteLeader (self):
         postUri = "/state/_promote";
         __data__ = None
